/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protegex.owl.jena.triplestore;

import edu.stanford.smi.protege.model.framestore.InMemoryFrameDb;
import edu.stanford.smi.protege.model.framestore.NarrowFrameStore;
import edu.stanford.smi.protegex.owl.jena.JenaOWLModel;
import edu.stanford.smi.protegex.owl.model.RDFResource;
import edu.stanford.smi.protegex.owl.model.triplestore.TripleStore;
import edu.stanford.smi.protegex.owl.model.triplestore.TripleStoreUtil;
import edu.stanford.smi.protegex.owl.model.triplestore.impl.AbstractTripleStoreModel;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

/**
 * @author Holger Knublauch  <holger@knublauch.com>
 */
public class JenaTripleStoreModel extends AbstractTripleStoreModel {

    private JenaOWLModel owlModel;


    public JenaTripleStoreModel(JenaOWLModel owlModel) {
        super(owlModel);
        this.owlModel = owlModel;
        initTripleStores();
    }
    
    public JenaTripleStoreModel(JenaOWLModel owlModel, NarrowFrameStore frameStore) {
      super(owlModel);
      this.owlModel = owlModel;
      ts.add(new JenaTripleStore(owlModel, frameStore, this));
      owlModel.resetJenaModel();
    }


    public TripleStore createTripleStore(String name) {
        NarrowFrameStore frameStore = new InMemoryFrameDb(name);
        String parentName = getActiveTripleStore().getName();
        mnfs.addActiveChildFrameStore(frameStore, parentName);
        TripleStore tripleStore = new JenaTripleStore(owlModel, frameStore, this);
        ts.add(tripleStore);
        updateRemoveFrameStores();
        return tripleStore;
    }


    public void deleteTripleStore(TripleStore tripleStore) {
        ts.remove(tripleStore);
        // TODO! mnfs.delete(tripleStore.getNarrowFrameStore());
    }


    public static void ensureActiveTripleStore(RDFResource resource) {
        TripleStoreUtil.ensureActiveTripleStore(resource);
    }


    public TripleStore getTripleStoreByDefaultNamespace(String namespace) {
        for (Iterator it = ts.iterator(); it.hasNext();) {
            TripleStore tripleStore = (TripleStore) it.next();
            if (namespace.equals(tripleStore.getDefaultNamespace())) {
                return tripleStore;
            }
        }
        return null;
    }


    private void initTripleStores() {
        ts = new ArrayList();
        NarrowFrameStore[] ss = (NarrowFrameStore[]) mnfs.getAvailableFrameStores().toArray(new NarrowFrameStore[0]);
        for (int i = 0; i < ss.length; i++) {
            NarrowFrameStore s = ss[i];
            ts.add(new JenaTripleStore(owlModel, s, this));
        }
        updateRemoveFrameStores();
    }


    private void updateRemoveFrameStores() {
        Collection allFrameStores = mnfs.getAvailableFrameStores();
        mnfs.setRemoveFrameStores(allFrameStores);
        owlModel.resetJenaModel();
    }
}
