/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protegex.owl.model.triplestore.impl;

import edu.stanford.smi.protege.model.Cls;
import edu.stanford.smi.protegex.owl.model.OWLAnonymousClass;
import edu.stanford.smi.protegex.owl.model.OWLModel;
import edu.stanford.smi.protegex.owl.model.OWLNamedClass;
import edu.stanford.smi.protegex.owl.model.RDFSNamedClass;
import edu.stanford.smi.protegex.owl.model.framestore.OWLFrameStore;

import java.util.*;

/**
 * @author Holger Knublauch  <holger@knublauch.com>
 */
class DuplicateSuperclassesPostProcessor {


    DuplicateSuperclassesPostProcessor(OWLModel owlModel) {
        OWLFrameStore owlFrameStore = owlModel.getOWLFrameStore();
        if (owlFrameStore != null) {
          owlFrameStore.setSuperclassSynchronizationBlocked(true);
        }
        Collection clses = owlModel.getUserDefinedOWLNamedClasses();
        Iterator it = clses.iterator();
        while (it.hasNext()) {
            OWLNamedClass cls = (OWLNamedClass) it.next();
            removeDuplicateSuperclasses(cls);
        }
        if (owlFrameStore != null) {
          owlFrameStore.setSuperclassSynchronizationBlocked(false);
        }
    }


    private void removeDuplicateSuperclasses(RDFSNamedClass cls) {
        List superclasses = new ArrayList(cls.getPureSuperclasses());
        Set bs = new HashSet();
        boolean hasDuplicates = false;
        for (Iterator it = superclasses.iterator(); it.hasNext();) {
            Cls superclass = (Cls) it.next();
            if (superclass instanceof OWLAnonymousClass) {
                String bt = superclass.getBrowserText();
                if (bs.contains(bt)) {
                    System.err.println("[DuplicateSuperclassesPostProcessor]  Class " + cls.getBrowserText() +
                            " has duplicate superclass " + bt);
                    hasDuplicates = true;
                    break;
                }
                else {
                    bs.add(bt);
                }
            }
        }
        if (hasDuplicates) {
            for (int i = 0; i < superclasses.size() - 1; i++) {
                if (superclasses.get(i) instanceof OWLAnonymousClass) {
                    OWLAnonymousClass anon = (OWLAnonymousClass) superclasses.get(i);
                    String browserTextI = anon.getBrowserText();
                    for (int j = superclasses.size() - 1; j > i; j--) {
                        if (superclasses.get(j).getClass() == anon.getClass()) {
                            OWLAnonymousClass classJ = (OWLAnonymousClass) superclasses.get(j);
                            String browserTextJ = classJ.getBrowserText();
                            if (browserTextJ.equals(browserTextI)) {
                                ((Cls) cls).removeDirectSuperclass(classJ);
                                superclasses.remove(j);
                            }
                        }
                    }
                }
            }
        }
    }
}
