/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protegex.owl.model.triplestore.impl;

import edu.stanford.smi.protege.util.Log;
import edu.stanford.smi.protegex.owl.model.OWLModel;
import edu.stanford.smi.protegex.owl.model.triplestore.TripleStore;

/**
 * A class that can be used to perform various post processing steps on an OWLModel
 * after triples have been changed.  This only delegates to other classes.
 *
 * @author Holger Knublauch  <holger@knublauch.com>
 */
public class TripleChangePostProcessor {

    //private static void aldi(OWLModel owlModel, TripleStore tripleStore) {
    //    for (Iterator it = tripleStore.listSubjects(owlModel.getRDFTypeProperty(), owlModel.getOWLOntologyClass()); it.hasNext();) {
    //        RDFResource subject = (RDFResource) it.next();
    //        System.out.println(" - " + subject.getBrowserText());
    //    }
    //}


    public static void postProcess(OWLModel owlModel) {
        TripleStore activeTripleStore = owlModel.getTripleStoreModel().getActiveTripleStore();

        {
            long startTime = System.currentTimeMillis();
            new RDFListPostProcessor(owlModel);
            log("Completed lists after " + (System.currentTimeMillis() - startTime) + " ms");
        }

        {
            long startTime = System.currentTimeMillis();
            new OWLAnonymousClassPostProcessor(owlModel);
            log("Completed anonymous classes after " + (System.currentTimeMillis() - startTime) + " ms");
        }

        {
            long startTime = System.currentTimeMillis();
            new OWLDeprecatedClassPostProcessor(owlModel);
            log("Completed deprecated classes after " + (System.currentTimeMillis() - startTime) + " ms");
        }

        {
            long startTime = System.currentTimeMillis();
            new RDFPropertyPostProcessor(owlModel);
            log("Completed properties after " + (System.currentTimeMillis() - startTime) + " ms");
        }

        {
            long startTime = System.currentTimeMillis();
            new RDFSNamedClassPostProcessor(owlModel);
            new DuplicateSuperclassesPostProcessor(owlModel);
            log("Completed named classes after " + (System.currentTimeMillis() - startTime) + " ms");
        }
        owlModel.getTripleStoreModel().setActiveTripleStore(activeTripleStore);
    }


    private static void log(String str) {
        Log.getLogger().info("[TripleChangePostProcessor] " + str);
    }
}
