/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */


// Info object representing a SWRL variable. A variable can be an argument to an atom or to a built-in. It is also used to pass results back
// from a built-in.

package edu.stanford.smi.protegex.owl.swrl.bridge;

import edu.stanford.smi.protegex.owl.swrl.model.*;
import edu.stanford.smi.protegex.owl.swrl.model.SWRLVariable;

public abstract class VariableInfo extends Info implements Argument
{
  // There is an equals methods defined for this class.
  private String variableName;

  public VariableInfo(SWRLVariable variable) 
  { 
    variableName = variable.getName();
  } // VariableInfo

  public String getVariableName() { return variableName; }

  public String toString() { return "?" + getVariableName(); }

  public boolean equals(Object obj)
  {
    if(this == obj) return true;
    if((obj == null) || (obj.getClass() != this.getClass())) return false;
    VariableInfo info = (VariableInfo)obj;
    return (getVariableName() == info.getVariableName() || getVariableName() != null && getVariableName().equals(info.getVariableName()));
  } // equals

  public int hashCode()
  {
    int hash = 78;
    hash = hash + (null == getVariableName() ? 0 : getVariableName().hashCode());
    return hash;
  } // hashCode

} // VariableInfo    
