/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */


package edu.stanford.smi.protegex.owl.swrl.ui.code;

import edu.stanford.smi.protegex.owl.model.OWLModel;
import edu.stanford.smi.protegex.owl.model.RDFResource;
import edu.stanford.smi.protegex.owl.swrl.model.SWRLNames;
import edu.stanford.smi.protegex.owl.swrl.model.SWRLVariable;
import edu.stanford.smi.protegex.owl.ui.code.OWLResourceNameMatcher;
import edu.stanford.smi.protegex.owl.ui.code.ResourceNameMatcher;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * @author Holger Knublauch  <holger@knublauch.com>
 */
public class SWRLResourceNameMatcher implements ResourceNameMatcher {

    public String getInsertString(RDFResource resource) {
        if (resource instanceof SWRLVariable) {
            return resource.getName();
        }
        else {
            return resource.getBrowserText();
        }
    }


    public List getMatchingResources(String prefix, String leftString, OWLModel owlModel) {
        List resources = new ArrayList();
        if (leftString.endsWith("?")) {
            for (Iterator it = owlModel.getOWLNamedClass(SWRLNames.Cls.VARIABLE).getInstances(true).iterator(); it.hasNext();) {
                SWRLVariable var = (SWRLVariable) it.next();
                if (var.getName().startsWith(prefix)) {
                    resources.add(var);
                }
            }
        }
        else if (prefix.length() > 0) {
            OWLResourceNameMatcher.getMatchingOWLNamedClasses(prefix, resources, owlModel);
            OWLResourceNameMatcher.getMatchingOWLIndividuals(prefix, resources, owlModel);
            OWLResourceNameMatcher.getMatchingOWLProperties(prefix, resources, owlModel);
        }
        return resources;
    }


}
