/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protegex.owl.ui.actions;

import edu.stanford.smi.protegex.owl.model.OWLModel;
import edu.stanford.smi.protegex.owl.ui.icons.OWLIcons;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

/**
 * A base class for OWLModelActions.
 *
 * @author Holger Knublauch  <holger@knublauch.com>
 */
public abstract class AbstractOWLModelAction implements OWLModelAction {

    private Set listeners = new HashSet();

    private boolean suitable = true;

    public static String CODE_MENU = "Code";

    public static String OWL_MENU = "OWL";

    public static String PROJECT_MENU = "Project";

    public static String TOOLS_MENU = "Tools";

	public static String WINDOW_MENU = "Window";


    public void addPropertyChangeListener(PropertyChangeListener listener) {
        listeners.add(listener);
    }


    public void dispose() {
        // Do nothing by default - overload to remove listeners etc
    }


    public Class getIconResourceClass() {
        return OWLIcons.class;
    }


    public String getIconFileName() {
        return null;
    }


    public String getToolbarPath() {
        return null;
    }


    public boolean isSuitable(OWLModel owlModel) {
        return suitable;
    }


    public void notifyPropertyChangeListeners(String propertyName, Object oldValue, Object newValue) {
        Iterator it = new ArrayList(listeners).iterator();
        while(it.hasNext()) {
            PropertyChangeListener listener = (PropertyChangeListener) it.next();
            listener.propertyChange(new PropertyChangeEvent(this, propertyName, oldValue, newValue));
        }
    }


    public void removePropertyChangeListener(PropertyChangeListener listener) {
        listeners.remove(listener);
    }
}
